using UnityEngine;
using System.Linq;
using System.Collections.Generic;

namespace Weapons
{
    public static class ResourcesLoader
{
    //Copyright by Morzzic © 2021. From Quickness - Thanks!
    private static Dictionary<string, Sprite> sprites = new Dictionary<string, Sprite>();
    private static Dictionary<string, AudioClip> clips = new Dictionary<string, AudioClip>();
    private static Dictionary<string, Texture2D> textures = new Dictionary<string, Texture2D>();

    public static void AddSprite(string name, string path, float scale = 1)
    {
        if (!sprites.ContainsKey(name)) sprites.Add(name, ModAPI.LoadSprite(path, scale));
    }
    
    public static Sprite FindSprite(string key)
    {
        return sprites.FirstOrDefault(x => x.Key == key).Value;
    }

    public static void AddSound(string name, string path)
    {
        if (!clips.ContainsKey(name)) clips.Add(name, ModAPI.LoadSound(path));
    }
    public static AudioClip FindSound(string key)
    {
        return clips.FirstOrDefault(x => x.Key == key).Value;
    }
    
    public static void AddTexture(string name, string path, bool pixelated = true)
    {
        if (!textures.ContainsKey(name)) textures.Add(name, ModAPI.LoadTexture(path, pixelated));
    }
    public static Texture2D FindTexture(string key)
    {
        return textures.FirstOrDefault(x => x.Key == key).Value;
    }
}
    public class Weapons
    {
        public static void Main()
        {
//Resources

    //pistols\\     
    ResourcesLoader.AddSprite("TEC9", "Weapons/Pistols/TEC9.png", 1f);
    ResourcesLoader.AddSprite("Mauser", "Weapons/Pistols/Mauser.png", 1f);
    ResourcesLoader.AddSprite("Taurus", "Weapons/Pistols/Taurus.png", 1f);
    ResourcesLoader.AddSprite("Short Revolver", "Weapons/Pistols/Short Revolver.png", 1f);
    ResourcesLoader.AddSprite("P8S", "Weapons/Pistols/P8S.png", 1f);
    ResourcesLoader.AddSprite("PSD", "Weapons/Pistols/PSD.png", 1f);
    ResourcesLoader.AddSprite("PM", "Weapons/Pistols/PM.png", 1f);
    ResourcesLoader.AddSprite("Dark revolver", "Weapons/Pistols/Dark revolver.png", 1f);
    ResourcesLoader.AddSprite("Pistol silenced", "Weapons/Pistols/Pistol silenced.png", 1f);
    ResourcesLoader.AddSprite("Sig Sauer", "Weapons/Pistols/Sig Sauer.png", 1f);
    ResourcesLoader.AddSprite("Hi Point", "Weapons/Pistols/Hi Point.png", 1f);
    ResourcesLoader.AddSprite("Five Seven", "Weapons/Pistols/Five Seven.png", 1f);
    ResourcesLoader.AddSprite("Luger", "Weapons/Pistols/Luger.png", 1f);
    ResourcesLoader.AddSprite("Crossman", "Weapons/Pistols/Crossman.png", 1f);
    ResourcesLoader.AddSprite("M1911", "Weapons/Pistols/M1911.png", 1f);
    ResourcesLoader.AddSprite("Pistol", "Weapons/Pistols/Pistol.png", 1f);
    ResourcesLoader.AddSprite("Berreta", "Weapons/Pistols/Berreta.png", 1f);
    ResourcesLoader.AddSprite("Glock16", "Weapons/Pistols/Glock16.png", 1f);
    ResourcesLoader.AddSprite("Tokarev", "Weapons/Pistols/Tokarev.png", 1f);
    ResourcesLoader.AddSprite("Kolibri (2 skin)", "Weapons/Pistols/Kolibri (2 skin).png", 1f);
    ResourcesLoader.AddSprite("Kolibri", "Weapons/Pistols/Kolibri.png", 1f);
    //submachine guns\\ 
    ResourcesLoader.AddSprite("Micro uzi (extended mag)", "Weapons/Submachine guns/Micro uzi (extended mag).png", 1f);
    ResourcesLoader.AddSprite("Micro Uzi", "Weapons/Submachine guns/Micro Uzi.png", 1f);
    ResourcesLoader.AddSprite("MP5K", "Weapons/Submachine guns/MP5K.png", 1f);
    ResourcesLoader.AddSprite("MP5SD", "Weapons/Submachine guns/MP5SD.png", 1f);
    ResourcesLoader.AddSprite("MP10", "Weapons/Submachine guns/MP10.png", 1f);
    ResourcesLoader.AddSprite("MP40", "Weapons/Submachine guns/MP40.png", 1f);
    ResourcesLoader.AddSprite("P90", "Weapons/Submachine guns/P90.png", 1f);
    ResourcesLoader.AddSprite("SCORPION CZ EVO", "Weapons/Submachine guns/SCORPION CZ EVO.png", 1f);
    ResourcesLoader.AddSprite("scorpion", "Weapons/Submachine guns/scorpion.png", 1f);
    ResourcesLoader.AddSprite("STEN", "Weapons/Submachine guns/STEN.png", 1f);
    ResourcesLoader.AddSprite("Submachine gun silenced", "Weapons/Submachine guns/Submachine gun silenced.png", 1f);
    ResourcesLoader.AddSprite("Thompson", "Weapons/Submachine guns/Thompson.png", 1f);
    ResourcesLoader.AddSprite("UZI (Extended Mag)", "Weapons/Submachine guns/UZI (Extended Mag).png", 1f);
    ResourcesLoader.AddSprite("UZI (Suppresor)", "Weapons/Submachine guns/UZI (Suppresor).png", 1f);
    ResourcesLoader.AddSprite("UZI", "Weapons/Submachine guns/UZI.png", 1f);

    //Shutters\\     
    ResourcesLoader.AddSprite("ShBerreta", "Weapons/Pistols/Additions/Berreta.png", 1f);
    ResourcesLoader.AddSprite("ShCrossman", "Weapons/Pistols/Additions/Crossman.png", 1f);
    ResourcesLoader.AddSprite("ShDark revolver", "Weapons/Pistols/Additions/Dark revolver.png", 1f);
    ResourcesLoader.AddSprite("ShFive Seven", "Weapons/Pistols/Additions/Five Seven.png", 1f);
    ResourcesLoader.AddSprite("ShGlock16", "Weapons/Pistols/Additions/Glock16.png", 1f);
    ResourcesLoader.AddSprite("ShHi Point", "Weapons/Pistols/Additions/Hi Point.png", 1f);
    ResourcesLoader.AddSprite("ShM1911", "Weapons/Pistols/Additions/M1911.png", 1f);
    ResourcesLoader.AddSprite("ShP8S", "Weapons/Pistols/Additions/P8S.png", 1f);
    ResourcesLoader.AddSprite("ShPistol silenced", "Weapons/Pistols/Additions/Pistol silenced.png", 1f);
    ResourcesLoader.AddSprite("ShPM", "Weapons/Pistols/Additions/PM.png", 1f);
    ResourcesLoader.AddSprite("ShPSD", "Weapons/Pistols/Additions/PSD.png", 1f);
    ResourcesLoader.AddSprite("ShShort Revolver", "Weapons/Pistols/Additions/Short Revolver.png", 1f);
    ResourcesLoader.AddSprite("ShSig Sauer", "Weapons/Pistols/Additions/Sig Sauer.png", 1f);
    ResourcesLoader.AddSprite("ShTaurus", "Weapons/Pistols/Additions/Taurus.png", 1f);
    ResourcesLoader.AddSprite("ShTEC9", "Weapons/Pistols/Additions/TEC9.png", 1f);
    ResourcesLoader.AddSprite("ShTokarev", "Weapons/Pistols/Additions/Tokarev.png", 1f);
    ResourcesLoader.AddSprite("ShMicro uzi (extended mag)", "Weapons/Submachine guns/Additions/Micro uzi (extended mag).png", 1f);
    ResourcesLoader.AddSprite("ShMicro Uzi", "Weapons/Submachine guns/Additions/Micro Uzi.png", 1f);
    ResourcesLoader.AddSprite("ShMP5K", "Weapons/Submachine guns/Additions/MP5K.png", 1f);
    ResourcesLoader.AddSprite("ShMP5SD", "Weapons/Submachine guns/Additions/MP5SD.png", 1f);
    ResourcesLoader.AddSprite("ShMP10", "Weapons/Submachine guns/Additions/MP10.png", 1f);
    ResourcesLoader.AddSprite("ShSCORPION CZ EVO", "Weapons/Submachine guns/Additions/SCORPION CZ EVO.png", 1f);
    ResourcesLoader.AddSprite("Shscorpion", "Weapons/Submachine guns/Additions/scorpion.png", 1f);
    ResourcesLoader.AddSprite("ShSubmachine gun silenced", "Weapons/Submachine guns/Additions/Submachine gun silenced.png", 1f);
    ResourcesLoader.AddSprite("ShThompson", "Weapons/Submachine guns/Additions/Thompson.png", 1f);
    ResourcesLoader.AddSprite("ShUZI (Extended Mag)", "Weapons/Submachine guns/Additions/UZI (Extended Mag).png", 1f);
    ResourcesLoader.AddSprite("ShUZI (Suppresor)", "Weapons/Submachine guns/Additions/UZI (Suppresor).png", 1f);
    ResourcesLoader.AddSprite("ShUZI", "Weapons/Submachine guns/Additions/UZI.png", 1f);

    ResourcesLoader.AddSound("Silenced 1", "Sfx/Silenced 1.mp3");
    ResourcesLoader.AddSound("SKolibri", "Sfx/Kolibri.mp3");
    ResourcesLoader.AddSound("Revl", "Sfx/Revl.mp3");
    ResourcesLoader.AddSound("Shor2", "Sfx/Shor2.mp3");
    ResourcesLoader.AddSound("Shot1", "Sfx/Shot1.mp3");
    ResourcesLoader.AddSound("SBerreta", "Sfx/Berreta.wav");
    ResourcesLoader.AddSound("SLuger", "Sfx/Luger.mp3");
    ResourcesLoader.AddSound("SMicro Uzi", "Sfx/Micro Uzi.mp3");
    ResourcesLoader.AddSound("SMP5K", "Sfx/MP5K.mp3");
    ResourcesLoader.AddSound("SMP5SD", "Sfx/MP5SD.mp3");
    ResourcesLoader.AddSound("SMP40", "Sfx/MP40.mp3");
    ResourcesLoader.AddSound("SP90", "Sfx/P90.mp3");
    ResourcesLoader.AddSound("SPM", "Sfx/PM.mp3");
    ResourcesLoader.AddSound("SThompson", "Sfx/Thompson.mp3");
    ResourcesLoader.AddSound("STaurus", "Sfx/Taurus.mp3");
    ResourcesLoader.AddSound("STEC-9", "Sfx/TEC-9.mp3");
    ResourcesLoader.AddSound("SMauser", "Sfx/Mauser.wav");
    ResourcesLoader.AddSound("Other", "Sfx/Other.wav");
//Code Pistols
                ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Pistol"),
                    NameOverride = "TEC9",
                    NameToOrderByOverride = "+VW3",
                    DescriptionOverride = " ",
                    CategoryOverride = ModAPI.FindCategory("Firearms"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbnail/TEC9.png"),
                    AfterSpawn = (Instance) =>
                    {
                        var Tec9Slide = Instance.transform.Find("Slide");
                        Tec9Slide.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("ShTEC9");

                        Instance.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("TEC9");
                        Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.25f, 0.1f); //Место выстрела

                        foreach (var c in Instance.GetComponents<Collider2D>())
                        {
                            GameObject.Destroy(c);
                        }
                        Instance.AddComponent<PolygonCollider2D>();        
                        Instance.FixColliders();
                        var firearm = Instance.GetComponent<FirearmBehaviour>();
			            Cartridge customCartridge = ModAPI.FindCartridge("50 AE"); //Патрон
                        customCartridge.name = "Weapon"; //Имя
                        customCartridge.Damage *= 0.7f; //Урон
                        customCartridge.StartSpeed *= 0.1f; //Скорость пули
                        customCartridge.PenetrationRandomAngleMultiplier *= 5f; //Точность через объекты
                        customCartridge.Recoil *= 0.2f; //Отдача
                        customCartridge.ImpactForce *= 0f; //Насколько сильно оттолкнет объект
			            firearm.Cartridge = customCartridge;
                        var phys = Instance.GetComponent<PhysicalBehaviour>();
                        phys.Properties = ModAPI.FindPhysicalProperties("Weapon");
                        phys.TrueInitialMass = 0.10f;
                        phys.InitialMass = 0.10f;
                        phys.rigidbody.mass = 0.10f;
  
                        firearm.BulletsPerShot = 1; //Пуль за выстрел
                        firearm.AutomaticFireInterval = 0.1f; //Скорострельность
                        firearm.Automatic = true; //Скорострельный или нет
                        firearm.InitialInaccuracy = 0f; //Разброс
                        
                        ModAPI.KeepExtraObjects(); 
                        firearm.ShotSounds = new AudioClip[]
						{
                            ResourcesLoader.FindSound("STEC-9")
						};          
				    }
				}
            );
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Pistol"),
                    NameOverride = "Mauser",
                    NameToOrderByOverride = "+VW3",
                    DescriptionOverride = " ",
                    CategoryOverride = ModAPI.FindCategory("Firearms"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbnail/Mauser.png"),
                    AfterSpawn = (Instance) =>
                    {
                        var MauserSlide = Instance.transform.Find("Slide");
                        MauserSlide.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("ShMauser");

                        Instance.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("Mauser");
                        Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.25f, 0.1f);

                        foreach (var c in Instance.GetComponents<Collider2D>())
                        {
                            GameObject.Destroy(c);
                        }
                        Instance.AddComponent<PolygonCollider2D>();        
                        Instance.FixColliders();
                        var firearm = Instance.GetComponent<FirearmBehaviour>();
			            Cartridge customCartridge = ModAPI.FindCartridge("50 AE");
                        customCartridge.name = "Weapon"; //Имя
                        customCartridge.Damage *= 2f; //Урон
                        customCartridge.StartSpeed *= 0.7f; //Скорость пули
                        customCartridge.PenetrationRandomAngleMultiplier *= 5f; //Точность через объекты
                        customCartridge.Recoil *= 0.2f; //Отдача
                        customCartridge.ImpactForce *= 0f; //Насколько сильно оттолкнет объект
			            firearm.Cartridge = customCartridge;
                        var phys = Instance.GetComponent<PhysicalBehaviour>();
                        phys.Properties = ModAPI.FindPhysicalProperties("Weapon");
                        phys.TrueInitialMass = 0.10f;
                        phys.InitialMass = 0.10f;
                        phys.rigidbody.mass = 0.10f;
  
                        firearm.BulletsPerShot = 1; //Пуль за выстрел
                        firearm.AutomaticFireInterval = 1f; //Скорострельность
                        firearm.Automatic = false; // 
                        firearm.InitialInaccuracy = 0f; //Разброс
                        
                        ModAPI.KeepExtraObjects();
                        firearm.ShotSounds = new AudioClip[]
						{
                            ResourcesLoader.FindSound("SMauser")
						};  			             
				    }
				}
            );
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Pistol"),
                    NameOverride = "Taurus",
                    NameToOrderByOverride = "+VW3",
                    DescriptionOverride = " ",
                    CategoryOverride = ModAPI.FindCategory("Firearms"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbnail/Taurus.png"),
                    AfterSpawn = (Instance) =>
                    {
                        var TaurusSlide = Instance.transform.Find("Slide");
                        TaurusSlide.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("ShTaurus");

                        Instance.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("Taurus");
                        Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.25f, 0.1f);

                        foreach (var c in Instance.GetComponents<Collider2D>())
                        {
                            GameObject.Destroy(c);
                        }
                        Instance.AddComponent<PolygonCollider2D>();        
                        Instance.FixColliders();
                        var firearm = Instance.GetComponent<FirearmBehaviour>();
			            Cartridge customCartridge = ModAPI.FindCartridge("50 AE");
                        customCartridge.name = "Weapon"; //Имя
                        customCartridge.Damage *= 0.7f; //Урон
                        customCartridge.StartSpeed *= 0.1f; //Скорость пули
                        customCartridge.PenetrationRandomAngleMultiplier *= 5f; //Точность через объекты
                        customCartridge.Recoil *= 0.2f; //Отдача
                        customCartridge.ImpactForce *= 0f; //Насколько сильно оттолкнет объект
			            firearm.Cartridge = customCartridge;
                        var phys = Instance.GetComponent<PhysicalBehaviour>();
                        phys.Properties = ModAPI.FindPhysicalProperties("Weapon");
                        phys.TrueInitialMass = 0.10f;
                        phys.InitialMass = 0.10f;
                        phys.rigidbody.mass = 0.10f;
  
                        firearm.BulletsPerShot = 1; //Пуль за выстрел
                        firearm.AutomaticFireInterval = 1f; //Скорострельность
                        firearm.Automatic = false; // 
                        firearm.InitialInaccuracy = 0f; //Разброс
                        
                        ModAPI.KeepExtraObjects(); 	
                        firearm.ShotSounds = new AudioClip[]
						{
                            ResourcesLoader.FindSound("STaurus")
						};		             
				    }
				}
            );
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Pistol"),
                    NameOverride = "Short Revolver",
                    NameToOrderByOverride = "+VW3",
                    DescriptionOverride = " ",
                    CategoryOverride = ModAPI.FindCategory("Firearms"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbnail/Short Revolver.png"),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("Short Revolver");
                        Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.25f, 0.1f);

                        foreach (var c in Instance.GetComponents<Collider2D>())
                        {
                            GameObject.Destroy(c);
                        }
                        Instance.AddComponent<PolygonCollider2D>();        
                        Instance.FixColliders();
                        var firearm = Instance.GetComponent<FirearmBehaviour>();
			            Cartridge customCartridge = ModAPI.FindCartridge("50 AE");
                        customCartridge.name = "Weapon"; //Имя
                        customCartridge.Damage *= 2f; //Урон
                        customCartridge.StartSpeed *= 0.7f; //Скорость пули
                        customCartridge.PenetrationRandomAngleMultiplier *= 5f; //Точность через объекты
                        customCartridge.Recoil *= 0.2f; //Отдача
                        customCartridge.ImpactForce *= 0f; //Насколько сильно оттолкнет объект
			            firearm.Cartridge = customCartridge;
                        var phys = Instance.GetComponent<PhysicalBehaviour>();
                        phys.Properties = ModAPI.FindPhysicalProperties("Weapon");
                        phys.TrueInitialMass = 0.10f;
                        phys.InitialMass = 0.10f;
                        phys.rigidbody.mass = 0.10f;
  
                        firearm.BulletsPerShot = 1; //Пуль за выстрел
                        firearm.AutomaticFireInterval = 1f; //Скорострельность
                        firearm.Automatic = false; // 
                        firearm.InitialInaccuracy = 0f; //Разброс
                    
                       	firearm.ShotSounds = new AudioClip[]
						{
                            ResourcesLoader.FindSound("SMauser")
						};		             
				    }
				}
            );
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Pistol"),
                    NameOverride = "P8S",
                    NameToOrderByOverride = "+VW3",
                    DescriptionOverride = " ",
                    CategoryOverride = ModAPI.FindCategory("Firearms"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbnail/P8S.png"),
                    AfterSpawn = (Instance) =>
                    {
                        var P8SSlide = Instance.transform.Find("Slide");
                        P8SSlide.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("ShP8S");

                        Instance.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("P8S");
                        Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.25f, 0.1f);

                        foreach (var c in Instance.GetComponents<Collider2D>())
                        {
                            GameObject.Destroy(c);
                        }
                        Instance.AddComponent<PolygonCollider2D>();        
                        Instance.FixColliders();
                        var firearm = Instance.GetComponent<FirearmBehaviour>();
			            Cartridge customCartridge = ModAPI.FindCartridge("50 AE");
                        customCartridge.name = "Weapon"; //Имя
                        customCartridge.Damage *= 0.7f; //Урон
                        customCartridge.StartSpeed *= 0.1f; //Скорость пули
                        customCartridge.PenetrationRandomAngleMultiplier *= 5f; //Точность через объекты
                        customCartridge.Recoil *= 0.2f; //Отдача
                        customCartridge.ImpactForce *= 0f; //Насколько сильно оттолкнет объект
			            firearm.Cartridge = customCartridge;
                        var phys = Instance.GetComponent<PhysicalBehaviour>();
                        phys.Properties = ModAPI.FindPhysicalProperties("Weapon");
                        phys.TrueInitialMass = 0.10f;
                        phys.InitialMass = 0.10f;
                        phys.rigidbody.mass = 0.10f;
  
                        firearm.BulletsPerShot = 1; //Пуль за выстрел
                        firearm.AutomaticFireInterval = 1f; //Скорострельность
                        firearm.Automatic = false; // 
                        firearm.InitialInaccuracy = 0f; //Разброс
                        
                        ModAPI.KeepExtraObjects();
                        firearm.ShotSounds = new AudioClip[]
						{
                            ResourcesLoader.FindSound("Shot1")
						}; 				             
				    }
				}
            );
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Pistol"),
                    NameOverride = "PSD",
                    NameToOrderByOverride = "+VW3",
                    DescriptionOverride = " ",
                    CategoryOverride = ModAPI.FindCategory("Firearms"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbnail/PSD.png"),
                    AfterSpawn = (Instance) =>
                    {
                        var PSDSlide = Instance.transform.Find("Slide");
                        PSDSlide.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("ShPSD");

                        Instance.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("PSD");
                        Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.25f, 0.1f);

                        foreach (var c in Instance.GetComponents<Collider2D>())
                        {
                            GameObject.Destroy(c);
                        }
                        Instance.AddComponent<PolygonCollider2D>();        
                        Instance.FixColliders();
                        var firearm = Instance.GetComponent<FirearmBehaviour>();
			            Cartridge customCartridge = ModAPI.FindCartridge("50 AE");
                        customCartridge.name = "Weapon"; //Имя
                        customCartridge.Damage *= 0.7f; //Урон
                        customCartridge.StartSpeed *= 0.1f; //Скорость пули
                        customCartridge.PenetrationRandomAngleMultiplier *= 5f; //Точность через объекты
                        customCartridge.Recoil *= 0.2f; //Отдача
                        customCartridge.ImpactForce *= 0f; //Насколько сильно оттолкнет объект
			            firearm.Cartridge = customCartridge;
                        var phys = Instance.GetComponent<PhysicalBehaviour>();
                        phys.Properties = ModAPI.FindPhysicalProperties("Weapon");
                        phys.TrueInitialMass = 0.10f;
                        phys.InitialMass = 0.10f;
                        phys.rigidbody.mass = 0.10f;
  
                        firearm.BulletsPerShot = 1; //Пуль за выстрел
                        firearm.AutomaticFireInterval = 1f; //Скорострельность
                        firearm.Automatic = false; // 
                        firearm.InitialInaccuracy = 0f; //Разброс
                        
                        ModAPI.KeepExtraObjects(); 
                        firearm.ShotSounds = new AudioClip[]
						{
                            ResourcesLoader.FindSound("Shot1")
						};				             
				    }
				}
            );
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Pistol"),
                    NameOverride = "PM",
                    NameToOrderByOverride = "+VW3",
                    DescriptionOverride = " ",
                    CategoryOverride = ModAPI.FindCategory("Firearms"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbnail/PM.png"),
                    AfterSpawn = (Instance) =>
                    {
                        var PMSlide = Instance.transform.Find("Slide");
                        PMSlide.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("ShPM");

                        Instance.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("PM");
                        Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.25f, 0.1f);

                        foreach (var c in Instance.GetComponents<Collider2D>())
                        {
                            GameObject.Destroy(c);
                        }
                        Instance.AddComponent<PolygonCollider2D>();        
                        Instance.FixColliders();
                        var firearm = Instance.GetComponent<FirearmBehaviour>();
			            Cartridge customCartridge = ModAPI.FindCartridge("50 AE");
                        customCartridge.name = "Weapon"; //Имя
                        customCartridge.Damage *= 0.7f; //Урон
                        customCartridge.StartSpeed *= 0.1f; //Скорость пули
                        customCartridge.PenetrationRandomAngleMultiplier *= 5f; //Точность через объекты
                        customCartridge.Recoil *= 0.2f; //Отдача
                        customCartridge.ImpactForce *= 0f; //Насколько сильно оттолкнет объект
			            firearm.Cartridge = customCartridge;
                        var phys = Instance.GetComponent<PhysicalBehaviour>();
                        phys.Properties = ModAPI.FindPhysicalProperties("Weapon");
                        phys.TrueInitialMass = 0.10f;
                        phys.InitialMass = 0.10f;
                        phys.rigidbody.mass = 0.10f;
  
                        firearm.BulletsPerShot = 1; //Пуль за выстрел
                        firearm.AutomaticFireInterval = 1f; //Скорострельность
                        firearm.Automatic = false; // 
                        firearm.InitialInaccuracy = 0f; //Разброс
                        
                        ModAPI.KeepExtraObjects(); 	
                        firearm.ShotSounds = new AudioClip[]
						{
                            ResourcesLoader.FindSound("SPM")
						};			             
				    }
				}
            );
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Pistol"),
                    NameOverride = "Dark revolver",
                    NameToOrderByOverride = "+VW3",
                    DescriptionOverride = " ",
                    CategoryOverride = ModAPI.FindCategory("Firearms"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbnail/Dark revolver.png"),
                    AfterSpawn = (Instance) =>
                    {

                        Instance.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("Dark revolver");
                        Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.25f, 0.1f);

                        foreach (var c in Instance.GetComponents<Collider2D>())
                        {
                            GameObject.Destroy(c);
                        }
                        Instance.AddComponent<PolygonCollider2D>();        
                        Instance.FixColliders();
                        var firearm = Instance.GetComponent<FirearmBehaviour>();
			            Cartridge customCartridge = ModAPI.FindCartridge("50 AE");
                        customCartridge.name = "Weapon"; //Имя
                        customCartridge.Damage *= 2f; //Урон
                        customCartridge.StartSpeed *= 0.7f; //Скорость пули
                        customCartridge.PenetrationRandomAngleMultiplier *= 5f; //Точность через объекты
                        customCartridge.Recoil *= 0.2f; //Отдача
                        customCartridge.ImpactForce *= 0f; //Насколько сильно оттолкнет объект
			            firearm.Cartridge = customCartridge;
                        var phys = Instance.GetComponent<PhysicalBehaviour>();
                        phys.Properties = ModAPI.FindPhysicalProperties("Weapon");
                        phys.TrueInitialMass = 0.10f;
                        phys.InitialMass = 0.10f;
                        phys.rigidbody.mass = 0.10f;
  
                        firearm.BulletsPerShot = 1; //Пуль за выстрел
                        firearm.AutomaticFireInterval = 1f; //Скорострельность
                        firearm.Automatic = false; // 
                        firearm.InitialInaccuracy = 0f; //Разброс
                        firearm.ShotSounds = new AudioClip[]
						{
                            ResourcesLoader.FindSound("SMauser")
						};
			             
				    }
				}
            );
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Pistol"),
                    NameOverride = "Pistol silenced",
                    NameToOrderByOverride = "+VW3",
                    DescriptionOverride = " ",
                    CategoryOverride = ModAPI.FindCategory("Firearms"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbnail/Pistol silenced.png"),
                    AfterSpawn = (Instance) =>
                    {
                        var PistolSilencedSlide = Instance.transform.Find("Slide");
                        PistolSilencedSlide.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("ShPistol silenced");

                        Instance.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("Pistol silenced");
                        Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.25f, 0.1f);

                        foreach (var c in Instance.GetComponents<Collider2D>())
                        {
                            GameObject.Destroy(c);
                        }
                        Instance.AddComponent<PolygonCollider2D>();        
                        Instance.FixColliders();
                        var firearm = Instance.GetComponent<FirearmBehaviour>();
			            Cartridge customCartridge = ModAPI.FindCartridge("50 AE");
                        customCartridge.name = "Weapon"; //Имя
                        customCartridge.Damage *= 0.7f; //Урон
                        customCartridge.StartSpeed *= 0.1f; //Скорость пули
                        customCartridge.PenetrationRandomAngleMultiplier *= 5f; //Точность через объекты
                        customCartridge.Recoil *= 0.2f; //Отдача
                        customCartridge.ImpactForce *= 0f; //Насколько сильно оттолкнет объект
			            firearm.Cartridge = customCartridge;
                        var phys = Instance.GetComponent<PhysicalBehaviour>();
                        phys.Properties = ModAPI.FindPhysicalProperties("Weapon");
                        phys.TrueInitialMass = 0.10f;
                        phys.InitialMass = 0.10f;
                        phys.rigidbody.mass = 0.10f;
  
                        firearm.BulletsPerShot = 1; //Пуль за выстрел
                        firearm.AutomaticFireInterval = 1f; //Скорострельность
                        firearm.Automatic = false; // 
                        firearm.InitialInaccuracy = 0f; //Разброс
                        
                        ModAPI.KeepExtraObjects(); 	
                        firearm.ShotSounds = new AudioClip[]
						{
                            ResourcesLoader.FindSound("Silenced 1")
						};			             
				    }
				}
            );
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Glock 17"),
                    NameOverride = "Sig Sauer",
                    NameToOrderByOverride = "+VW3",
                    DescriptionOverride = " ",
                    CategoryOverride = ModAPI.FindCategory("Firearms"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbnail/Sig Sauer.png"),
                    AfterSpawn = (Instance) =>
                    {
                        var SigSauerSlide = Instance.transform.Find("Slide");
                        SigSauerSlide.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("ShSig Sauer");

                        Instance.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("Sig Sauer");
                        Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.25f, 0.1f);

                        foreach (var c in Instance.GetComponents<Collider2D>())
                        {
                            GameObject.Destroy(c);
                        }
                        Instance.AddComponent<PolygonCollider2D>();        
                        Instance.FixColliders();
                        var firearm = Instance.GetComponent<FirearmBehaviour>();
			            Cartridge customCartridge = ModAPI.FindCartridge("50 AE");
                        customCartridge.name = "Weapon"; //Имя
                        customCartridge.Damage *= 0.7f; //Урон
                        customCartridge.StartSpeed *= 0.1f; //Скорость пули
                        customCartridge.PenetrationRandomAngleMultiplier *= 5f; //Точность через объекты
                        customCartridge.Recoil *= 0.2f; //Отдача
                        customCartridge.ImpactForce *= 0f; //Насколько сильно оттолкнет объект
			            firearm.Cartridge = customCartridge;
                        var phys = Instance.GetComponent<PhysicalBehaviour>();
                        phys.Properties = ModAPI.FindPhysicalProperties("Weapon");
                        phys.TrueInitialMass = 0.10f;
                        phys.InitialMass = 0.10f;
                        phys.rigidbody.mass = 0.10f;
  
                        firearm.BulletsPerShot = 1; //Пуль за выстрел
                        firearm.AutomaticFireInterval = 1f; //Скорострельность
                        firearm.Automatic = false; // 
                        firearm.InitialInaccuracy = 0f; //Разброс
                        
                        ModAPI.KeepExtraObjects(); 	
                      		             
				    }
				}
            );
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Glock 17"),
                    NameOverride = "Hi Point",
                    NameToOrderByOverride = "+VW3",
                    DescriptionOverride = " ",
                    CategoryOverride = ModAPI.FindCategory("Firearms"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbnail/Hi Point.png"),
                    AfterSpawn = (Instance) =>
                    {
                        var HiPointSlide = Instance.transform.Find("Slide");
                        HiPointSlide.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("ShHi Point");

                        Instance.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("Hi Point");
                        Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.25f, 0.1f);

                        foreach (var c in Instance.GetComponents<Collider2D>())
                        {
                            GameObject.Destroy(c);
                        }
                        Instance.AddComponent<PolygonCollider2D>();        
                        Instance.FixColliders();
                        var firearm = Instance.GetComponent<FirearmBehaviour>();
			            Cartridge customCartridge = ModAPI.FindCartridge("50 AE");
                        customCartridge.name = "Weapon"; //Имя
                        customCartridge.Damage *= 0.7f; //Урон
                        customCartridge.StartSpeed *= 0.1f; //Скорость пули
                        customCartridge.PenetrationRandomAngleMultiplier *= 5f; //Точность через объекты
                        customCartridge.Recoil *= 0.2f; //Отдача
                        customCartridge.ImpactForce *= 0f; //Насколько сильно оттолкнет объект
			            firearm.Cartridge = customCartridge;
                        var phys = Instance.GetComponent<PhysicalBehaviour>();
                        phys.Properties = ModAPI.FindPhysicalProperties("Weapon");
                        phys.TrueInitialMass = 0.10f;
                        phys.InitialMass = 0.10f;
                        phys.rigidbody.mass = 0.10f;
  
                        firearm.BulletsPerShot = 1; //Пуль за выстрел
                        firearm.AutomaticFireInterval = 1f; //Скорострельность
                        firearm.Automatic = false; // 
                        firearm.InitialInaccuracy = 0f; //Разброс
                        
                        ModAPI.KeepExtraObjects(); 
                        ;				             
				    }
				}
            );
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Pistol"),
                    NameOverride = "Five Seven",
                    NameToOrderByOverride = "+VW3",
                    DescriptionOverride = " ",
                    CategoryOverride = ModAPI.FindCategory("Firearms"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbnail/Five Seven.png"),
                    AfterSpawn = (Instance) =>
                    {
                        var FiveSevenSlide = Instance.transform.Find("Slide");
                        FiveSevenSlide.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("ShFive Seven");

                        Instance.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("Five Seven");
                        Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.25f, 0.1f);

                        foreach (var c in Instance.GetComponents<Collider2D>())
                        {
                            GameObject.Destroy(c);
                        }
                        Instance.AddComponent<PolygonCollider2D>();        
                        Instance.FixColliders();
                        var firearm = Instance.GetComponent<FirearmBehaviour>();
			            Cartridge customCartridge = ModAPI.FindCartridge("50 AE");
                        customCartridge.name = "Weapon"; //Имя
                        customCartridge.Damage *= 0.7f; //Урон
                        customCartridge.StartSpeed *= 0.1f; //Скорость пули
                        customCartridge.PenetrationRandomAngleMultiplier *= 5f; //Точность через объекты
                        customCartridge.Recoil *= 0.2f; //Отдача
                        customCartridge.ImpactForce *= 0f; //Насколько сильно оттолкнет объект
			            firearm.Cartridge = customCartridge;
                        var phys = Instance.GetComponent<PhysicalBehaviour>();
                        phys.Properties = ModAPI.FindPhysicalProperties("Weapon");
                        phys.TrueInitialMass = 0.10f;
                        phys.InitialMass = 0.10f;
                        phys.rigidbody.mass = 0.10f;
  
                        firearm.BulletsPerShot = 1; //Пуль за выстрел
                        firearm.AutomaticFireInterval = 1f; //Скорострельность
                        firearm.Automatic = false; // 
                        firearm.InitialInaccuracy = 0f; //Разброс
                        
                        ModAPI.KeepExtraObjects(); 	
                        firearm.ShotSounds = new AudioClip[]
						{
                            ResourcesLoader.FindSound("Shot1")
						};			             
				    }
				}
            );
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Pistol"),
                    NameOverride = "Luger",
                    NameToOrderByOverride = "+VW3",
                    DescriptionOverride = " ",
                    CategoryOverride = ModAPI.FindCategory("Firearms"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbnail/Luger.png"),
                    AfterSpawn = (Instance) =>
                    {
                        var LugerSlide = Instance.transform.Find("Slide");
                        LugerSlide.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("ShLuger");

                        Instance.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("Luger");
                        Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.25f, 0.1f);

                        foreach (var c in Instance.GetComponents<Collider2D>())
                        {
                            GameObject.Destroy(c);
                        }
                        Instance.AddComponent<PolygonCollider2D>();        
                        Instance.FixColliders();
                        var firearm = Instance.GetComponent<FirearmBehaviour>();
			            Cartridge customCartridge = ModAPI.FindCartridge("50 AE");
                        customCartridge.name = "Weapon"; //Имя
                        customCartridge.Damage *= 0.7f; //Урон
                        customCartridge.StartSpeed *= 0.1f; //Скорость пули
                        customCartridge.PenetrationRandomAngleMultiplier *= 5f; //Точность через объекты
                        customCartridge.Recoil *= 0.2f; //Отдача
                        customCartridge.ImpactForce *= 0f; //Насколько сильно оттолкнет объект
			            firearm.Cartridge = customCartridge;
                        var phys = Instance.GetComponent<PhysicalBehaviour>();
                        phys.Properties = ModAPI.FindPhysicalProperties("Weapon");
                        phys.TrueInitialMass = 0.10f;
                        phys.InitialMass = 0.10f;
                        phys.rigidbody.mass = 0.10f;
  
                        firearm.BulletsPerShot = 1; //Пуль за выстрел
                        firearm.AutomaticFireInterval = 1f; //Скорострельность
                        firearm.Automatic = false; // 
                        firearm.InitialInaccuracy = 0f; //Разброс
                        
                        ModAPI.KeepExtraObjects();
                        firearm.ShotSounds = new AudioClip[]
						{
                            ResourcesLoader.FindSound("SLuger")
						}; 				             
				    }
				}
            );
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Pistol"),
                    NameOverride = "Crossman",
                    NameToOrderByOverride = "+VW3",
                    DescriptionOverride = " ",
                    CategoryOverride = ModAPI.FindCategory("Firearms"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbnail/Crossman.png"),
                    AfterSpawn = (Instance) =>
                    {
                        var CrossmanSlide = Instance.transform.Find("Slide");
                        CrossmanSlide.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("ShCrossman");

                        Instance.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("Crossman");
                        Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.25f, 0.1f);

                        foreach (var c in Instance.GetComponents<Collider2D>())
                        {
                            GameObject.Destroy(c);
                        }
                        Instance.AddComponent<PolygonCollider2D>();        
                        Instance.FixColliders();
                        var firearm = Instance.GetComponent<FirearmBehaviour>();
			            Cartridge customCartridge = ModAPI.FindCartridge("50 AE");
                        customCartridge.name = "Weapon"; //Имя
                        customCartridge.Damage *= 0.7f; //Урон
                        customCartridge.StartSpeed *= 0.1f; //Скорость пули
                        customCartridge.PenetrationRandomAngleMultiplier *= 5f; //Точность через объекты
                        customCartridge.Recoil *= 0.2f; //Отдача
                        customCartridge.ImpactForce *= 0f; //Насколько сильно оттолкнет объект
			            firearm.Cartridge = customCartridge;
                        var phys = Instance.GetComponent<PhysicalBehaviour>();
                        phys.Properties = ModAPI.FindPhysicalProperties("Weapon");
                        phys.TrueInitialMass = 0.10f;
                        phys.InitialMass = 0.10f;
                        phys.rigidbody.mass = 0.10f;
  
                        firearm.BulletsPerShot = 1; //Пуль за выстрел
                        firearm.AutomaticFireInterval = 1f; //Скорострельность
                        firearm.Automatic = false; // 
                        firearm.InitialInaccuracy = 0f; //Разброс
                        
                        ModAPI.KeepExtraObjects(); 
                        firearm.ShotSounds = new AudioClip[]
						{
                            ResourcesLoader.FindSound("Shot1")
						};				             
				    }
				}
            );
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Pistol"),
                    NameOverride = "M1911",
                    NameToOrderByOverride = "+VW3",
                    DescriptionOverride = " ",
                    CategoryOverride = ModAPI.FindCategory("Firearms"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbnail/M1911.png"),
                    AfterSpawn = (Instance) =>
                    {
                        var M1911Slide = Instance.transform.Find("Slide");
                        M1911Slide.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("ShM1911");

                        Instance.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("M1911");
                        Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.25f, 0.1f);

                        foreach (var c in Instance.GetComponents<Collider2D>())
                        {
                            GameObject.Destroy(c);
                        }
                        Instance.AddComponent<PolygonCollider2D>();        
                        Instance.FixColliders();
                        var firearm = Instance.GetComponent<FirearmBehaviour>();
			            Cartridge customCartridge = ModAPI.FindCartridge("50 AE");
                        customCartridge.name = "Weapon"; //Имя
                        customCartridge.Damage *= 0.7f; //Урон
                        customCartridge.StartSpeed *= 0.1f; //Скорость пули
                        customCartridge.PenetrationRandomAngleMultiplier *= 5f; //Точность через объекты
                        customCartridge.Recoil *= 0.2f; //Отдача
                        customCartridge.ImpactForce *= 0f; //Насколько сильно оттолкнет объект
			            firearm.Cartridge = customCartridge;
                        var phys = Instance.GetComponent<PhysicalBehaviour>();
                        phys.Properties = ModAPI.FindPhysicalProperties("Weapon");
                        phys.TrueInitialMass = 0.10f;
                        phys.InitialMass = 0.10f;
                        phys.rigidbody.mass = 0.10f;
  
                        firearm.BulletsPerShot = 1; //Пуль за выстрел
                        firearm.AutomaticFireInterval = 1f; //Скорострельность
                        firearm.Automatic = false; // 
                        firearm.InitialInaccuracy = 0f; //Разброс
                        
                        ModAPI.KeepExtraObjects(); 	
                        firearm.ShotSounds = new AudioClip[]
						{
                            ResourcesLoader.FindSound("Shot1")
						};			             
				    }
				}
            );
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Pistol"),
                    NameOverride = "Berreta",
                    NameToOrderByOverride = "+VW3",
                    DescriptionOverride = " ",
                    CategoryOverride = ModAPI.FindCategory("Firearms"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbnail/Berreta.png"),
                    AfterSpawn = (Instance) =>
                    {
                        var BerretaSlide = Instance.transform.Find("Slide");
                        BerretaSlide.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("ShBerreta");

                        Instance.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("Berreta");
                        Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.25f, 0.1f);

                        foreach (var c in Instance.GetComponents<Collider2D>())
                        {
                            GameObject.Destroy(c);
                        }
                        Instance.AddComponent<PolygonCollider2D>();        
                        Instance.FixColliders();
                        var firearm = Instance.GetComponent<FirearmBehaviour>();
			            Cartridge customCartridge = ModAPI.FindCartridge("50 AE");
                        customCartridge.name = "Weapon"; //Имя
                        customCartridge.Damage *= 0.7f; //Урон
                        customCartridge.StartSpeed *= 0.1f; //Скорость пули
                        customCartridge.PenetrationRandomAngleMultiplier *= 5f; //Точность через объекты
                        customCartridge.Recoil *= 0.2f; //Отдача
                        customCartridge.ImpactForce *= 0f; //Насколько сильно оттолкнет объект
			            firearm.Cartridge = customCartridge;
                        var phys = Instance.GetComponent<PhysicalBehaviour>();
                        phys.Properties = ModAPI.FindPhysicalProperties("Weapon");
                        phys.TrueInitialMass = 0.10f;
                        phys.InitialMass = 0.10f;
                        phys.rigidbody.mass = 0.10f;
  
                        firearm.BulletsPerShot = 1; //Пуль за выстрел
                        firearm.AutomaticFireInterval = 1f; //Скорострельность
                        firearm.Automatic = false; // 
                        firearm.InitialInaccuracy = 0f; //Разброс
                        
                        ModAPI.KeepExtraObjects(); 	
                        firearm.ShotSounds = new AudioClip[]
						{
                            ResourcesLoader.FindSound("SBerreta")
						};			             
				    }
				}
            );
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Glock 16"),
                    NameOverride = "Glock16",
                    NameToOrderByOverride = "+VW3",
                    DescriptionOverride = " ",
                    CategoryOverride = ModAPI.FindCategory("Firearms"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbnail/Glock16.png"),
                    AfterSpawn = (Instance) =>
                    {
                        var Glock16Slide = Instance.transform.Find("Slide");
                        Glock16Slide.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("ShGlock16");

                        Instance.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("Glock16");
                        Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.25f, 0.1f);

                        foreach (var c in Instance.GetComponents<Collider2D>())
                        {
                            GameObject.Destroy(c);
                        }
                        Instance.AddComponent<PolygonCollider2D>();        
                        Instance.FixColliders();
                        var firearm = Instance.GetComponent<FirearmBehaviour>();
			            Cartridge customCartridge = ModAPI.FindCartridge("50 AE");
                        customCartridge.name = "Weapon"; //Имя
                        customCartridge.Damage *= 0.7f; //Урон
                        customCartridge.StartSpeed *= 0.1f; //Скорость пули
                        customCartridge.PenetrationRandomAngleMultiplier *= 5f; //Точность через объекты
                        customCartridge.Recoil *= 0.2f; //Отдача
                        customCartridge.ImpactForce *= 0f; //Насколько сильно оттолкнет объект
			            firearm.Cartridge = customCartridge;
                        var phys = Instance.GetComponent<PhysicalBehaviour>();
                        phys.Properties = ModAPI.FindPhysicalProperties("Weapon");
                        phys.TrueInitialMass = 0.10f;
                        phys.InitialMass = 0.10f;
                        phys.rigidbody.mass = 0.10f;
  
                        firearm.BulletsPerShot = 1; //Пуль за выстрел
                        firearm.AutomaticFireInterval = 1f; //Скорострельность
                        firearm.Automatic = false; // 
                        firearm.InitialInaccuracy = 0f; //Разброс
                        
                        ModAPI.KeepExtraObjects(); 	
                        firearm.ShotSounds = new AudioClip[]
						{
                            ResourcesLoader.FindSound("Shot1")
						};			             
				    }
				}
            );
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Pistol"),
                    NameOverride = "Tokarev",
                    NameToOrderByOverride = "+VW3",
                    DescriptionOverride = " ",
                    CategoryOverride = ModAPI.FindCategory("Firearms"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbnail/Tokarev.png"),
                    AfterSpawn = (Instance) =>
                    {
                        var TokarevSlide = Instance.transform.Find("Slide");
                        TokarevSlide.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("ShTokarev");

                        Instance.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("Tokarev");
                        Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.25f, 0.1f);

                        foreach (var c in Instance.GetComponents<Collider2D>())
                        {
                            GameObject.Destroy(c);
                        }
                        Instance.AddComponent<PolygonCollider2D>();        
                        Instance.FixColliders();
                        var firearm = Instance.GetComponent<FirearmBehaviour>();
			            Cartridge customCartridge = ModAPI.FindCartridge("50 AE");
                        customCartridge.name = "Weapon"; //Имя
                        customCartridge.Damage *= 0.7f; //Урон
                        customCartridge.StartSpeed *= 0.1f; //Скорость пули
                        customCartridge.PenetrationRandomAngleMultiplier *= 5f; //Точность через объекты
                        customCartridge.Recoil *= 0.2f; //Отдача
                        customCartridge.ImpactForce *= 0f; //Насколько сильно оттолкнет объект
			            firearm.Cartridge = customCartridge;
                        var phys = Instance.GetComponent<PhysicalBehaviour>();
                        phys.Properties = ModAPI.FindPhysicalProperties("Weapon");
                        phys.TrueInitialMass = 0.10f;
                        phys.InitialMass = 0.10f;
                        phys.rigidbody.mass = 0.10f;
  
                        firearm.BulletsPerShot = 1; //Пуль за выстрел
                        firearm.AutomaticFireInterval = 1f; //Скорострельность
                        firearm.Automatic = false; // 
                        firearm.InitialInaccuracy = 0f; //Разброс
                        
                        ModAPI.KeepExtraObjects(); 	
                        firearm.ShotSounds = new AudioClip[]
						{
                            ResourcesLoader.FindSound("Other")
						};			             
				    }
				}
            );
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Pistol"),
                    NameOverride = "Kolibri",
                    NameToOrderByOverride = "+VW3",
                    DescriptionOverride = " ",
                    CategoryOverride = ModAPI.FindCategory("Firearms"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbnail/Kolibri.png"),
                    AfterSpawn = (Instance) =>
                    {
                        var Kolibri1Slide = Instance.transform.Find("Slide");
                        Kolibri1Slide.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("ShKolibri");

                        Instance.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("Kolibri");
                        Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.25f, 0.1f);

                        foreach (var c in Instance.GetComponents<Collider2D>())
                        {
                            GameObject.Destroy(c);
                        }
                        Instance.AddComponent<PolygonCollider2D>();        
                        Instance.FixColliders();
                        var firearm = Instance.GetComponent<FirearmBehaviour>();
			            Cartridge customCartridge = ModAPI.FindCartridge("50 AE");
                        customCartridge.name = "Weapon"; //Имя
                        customCartridge.Damage *= 0.7f; //Урон
                        customCartridge.StartSpeed *= 0.1f; //Скорость пули
                        customCartridge.PenetrationRandomAngleMultiplier *= 5f; //Точность через объекты
                        customCartridge.Recoil *= 0.2f; //Отдача
                        customCartridge.ImpactForce *= 0f; //Насколько сильно оттолкнет объект
			            firearm.Cartridge = customCartridge;
                        var phys = Instance.GetComponent<PhysicalBehaviour>();
                        phys.Properties = ModAPI.FindPhysicalProperties("Weapon");
                        phys.TrueInitialMass = 0.10f;
                        phys.InitialMass = 0.10f;
                        phys.rigidbody.mass = 0.10f;
  
                        firearm.BulletsPerShot = 1; //Пуль за выстрел
                        firearm.AutomaticFireInterval = 1f; //Скорострельность
                        firearm.Automatic = false; // 
                        firearm.InitialInaccuracy = 0f; //Разброс
                        
                        ModAPI.KeepExtraObjects(); 
                        firearm.ShotSounds = new AudioClip[]
						{
                            ResourcesLoader.FindSound("SKolibri")
						};				             
				    }
				}
            );
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Pistol"),
                    NameOverride = "Kolibri (2 skin)",
                    NameToOrderByOverride = "+VW3",
                    DescriptionOverride = " ",
                    CategoryOverride = ModAPI.FindCategory("Firearms"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbnail/Kolibri (2 skin).png"),
                    AfterSpawn = (Instance) =>
                    {
                        var Kolibri2Slide = Instance.transform.Find("Slide");
                        Kolibri2Slide.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("ShKolibri (2 skin)");

                        Instance.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("Kolibri (2 skin)");
                        Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.25f, 0.1f);

                        foreach (var c in Instance.GetComponents<Collider2D>())
                        {
                            GameObject.Destroy(c);
                        }
                        Instance.AddComponent<PolygonCollider2D>();        
                        Instance.FixColliders();
                        var firearm = Instance.GetComponent<FirearmBehaviour>();
			            Cartridge customCartridge = ModAPI.FindCartridge("50 AE");
                        customCartridge.name = "Weapon"; //Имя
                        customCartridge.Damage *= 0.7f; //Урон
                        customCartridge.StartSpeed *= 0.1f; //Скорость пули
                        customCartridge.PenetrationRandomAngleMultiplier *= 5f; //Точность через объекты
                        customCartridge.Recoil *= 0.2f; //Отдача
                        customCartridge.ImpactForce *= 0f; //Насколько сильно оттолкнет объект
			            firearm.Cartridge = customCartridge;
                        var phys = Instance.GetComponent<PhysicalBehaviour>();
                        phys.Properties = ModAPI.FindPhysicalProperties("Weapon");
                        phys.TrueInitialMass = 0.10f;
                        phys.InitialMass = 0.10f;
                        phys.rigidbody.mass = 0.10f;
  
                        firearm.BulletsPerShot = 1; //Пуль за выстрел
                        firearm.AutomaticFireInterval = 1f; //Скорострельность
                        firearm.Automatic = false; // 
                        firearm.InitialInaccuracy = 0f; //Разброс
                        
                        ModAPI.KeepExtraObjects(); 	
                        firearm.ShotSounds = new AudioClip[]
						{
                            ResourcesLoader.FindSound("SKolibri")
						};			             
				    }
				}
            );
//Code SM            
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Pistol"),
                    NameOverride = "Micro Uzi",
                    NameToOrderByOverride = "+VW3",
                    DescriptionOverride = " ",
                    CategoryOverride = ModAPI.FindCategory("Firearms"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbnail/Micro Uzi.png"),
                    AfterSpawn = (Instance) =>
                    {
                        var Tec9Slide = Instance.transform.Find("Slide");
                        Tec9Slide.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("ShMicro Uzi");

                        Instance.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("Micro Uzi");
                        Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.23f, 0.12f); //Место выстрела

                        foreach (var c in Instance.GetComponents<Collider2D>())
                        {
                            GameObject.Destroy(c);
                        }
                        Instance.AddComponent<PolygonCollider2D>();        
                        Instance.FixColliders();
                        var firearm = Instance.GetComponent<FirearmBehaviour>();
			            Cartridge customCartridge = ModAPI.FindCartridge("50 AE"); //Патрон
                        customCartridge.name = "Weapon"; //Имя
                        customCartridge.Damage *= 0.5f; //Урон
                        customCartridge.StartSpeed *= 0.1f; //Скорость пули
                        customCartridge.PenetrationRandomAngleMultiplier *= 5f; //Точность через объекты
                        customCartridge.Recoil *= 0.5f; //Отдача
                        customCartridge.ImpactForce *= 0f; //Насколько сильно оттолкнет объект
			            firearm.Cartridge = customCartridge;
                        var phys = Instance.GetComponent<PhysicalBehaviour>();
                        phys.Properties = ModAPI.FindPhysicalProperties("Weapon");
                        phys.TrueInitialMass = 0.10f;
                        phys.InitialMass = 0.10f;
                        phys.rigidbody.mass = 0.10f;
  
                        firearm.BulletsPerShot = 1; //Пуль за выстрел
                        firearm.AutomaticFireInterval = 0.08f; //Скорострельность
                        firearm.Automatic = true; //Скорострельный или нет
                        firearm.InitialInaccuracy = 0f; //Разброс
                        
                        ModAPI.KeepExtraObjects(); 
                        firearm.ShotSounds = new AudioClip[]
						{
                            ResourcesLoader.FindSound("SMicro Uzi")
						};          
				    }
				}
            );
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Pistol"),
                    NameOverride = "MP5K",
                    NameToOrderByOverride = "+VW3",
                    DescriptionOverride = " ",
                    CategoryOverride = ModAPI.FindCategory("Firearms"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbnail/MP5K.png"),
                    AfterSpawn = (Instance) =>
                    {
                        var Tec9Slide = Instance.transform.Find("Slide");
                        Tec9Slide.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("ShMP5K");

                        Instance.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("MP5K");
                        Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.25f, 0.1f); //Место выстрела

                        foreach (var c in Instance.GetComponents<Collider2D>())
                        {
                            GameObject.Destroy(c);
                        }
                        Instance.AddComponent<PolygonCollider2D>();        
                        Instance.FixColliders();
                        var firearm = Instance.GetComponent<FirearmBehaviour>();
			            Cartridge customCartridge = ModAPI.FindCartridge("50 AE"); //Патрон
                        customCartridge.name = "Weapon"; //Имя
                        customCartridge.Damage *= 0.7f; //Урон
                        customCartridge.StartSpeed *= 0.1f; //Скорость пули
                        customCartridge.PenetrationRandomAngleMultiplier *= 5f; //Точность через объекты
                        customCartridge.Recoil *= 0.2f; //Отдача
                        customCartridge.ImpactForce *= 0f; //Насколько сильно оттолкнет объект
			            firearm.Cartridge = customCartridge;
                        var phys = Instance.GetComponent<PhysicalBehaviour>();
                        phys.Properties = ModAPI.FindPhysicalProperties("Weapon");
                        phys.TrueInitialMass = 0.10f;
                        phys.InitialMass = 0.10f;
                        phys.rigidbody.mass = 0.10f;
  
                        firearm.BulletsPerShot = 1; //Пуль за выстрел
                        firearm.AutomaticFireInterval = 0.15f; //Скорострельность
                        firearm.Automatic = true; //Скорострельный или нет
                        firearm.InitialInaccuracy = 0f; //Разброс
                        
                        ModAPI.KeepExtraObjects(); 
                        firearm.ShotSounds = new AudioClip[]
						{
                            ResourcesLoader.FindSound("SMP5K")
						};          
				    }
				}
            );
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Pistol"),
                    NameOverride = "MP5SD",
                    NameToOrderByOverride = "+VW3",
                    DescriptionOverride = " ",
                    CategoryOverride = ModAPI.FindCategory("Firearms"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbnail/MP5SD.png"),
                    AfterSpawn = (Instance) =>
                    {
                        var Tec9Slide = Instance.transform.Find("Slide");
                        Tec9Slide.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("ShMMP5SD");

                        Instance.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("MP5SD");
                        Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.45f, 0.1f); //Место выстрела

                        foreach (var c in Instance.GetComponents<Collider2D>())
                        {
                            GameObject.Destroy(c);
                        }
                        Instance.AddComponent<PolygonCollider2D>();        
                        Instance.FixColliders();
                        var firearm = Instance.GetComponent<FirearmBehaviour>();
			            Cartridge customCartridge = ModAPI.FindCartridge("50 AE"); //Патрон
                        customCartridge.name = "Weapon"; //Имя
                        customCartridge.Damage *= 0.7f; //Урон
                        customCartridge.StartSpeed *= 0.1f; //Скорость пули
                        customCartridge.PenetrationRandomAngleMultiplier *= 5f; //Точность через объекты
                        customCartridge.Recoil *= 0.2f; //Отдача
                        customCartridge.ImpactForce *= 0f; //Насколько сильно оттолкнет объект
			            firearm.Cartridge = customCartridge;
                        var phys = Instance.GetComponent<PhysicalBehaviour>();
                        phys.Properties = ModAPI.FindPhysicalProperties("Weapon");
                        phys.TrueInitialMass = 0.10f;
                        phys.InitialMass = 0.10f;
                        phys.rigidbody.mass = 0.10f;
  
                        firearm.BulletsPerShot = 1; //Пуль за выстрел
                        firearm.AutomaticFireInterval = 0.11f; //Скорострельность
                        firearm.Automatic = true; //Скорострельный или нет
                        firearm.InitialInaccuracy = 0f; //Разброс
                        
                        ModAPI.KeepExtraObjects(); 
                        firearm.ShotSounds = new AudioClip[]
						{
                            ResourcesLoader.FindSound("SMP5SD")
						};          
				    }
				}
            );
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Pistol"),
                    NameOverride = "MP10",
                    NameToOrderByOverride = "+VW3",
                    DescriptionOverride = " ",
                    CategoryOverride = ModAPI.FindCategory("Firearms"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbnail/MP10.png"),
                    AfterSpawn = (Instance) =>
                    {
                        var Tec9Slide = Instance.transform.Find("Slide");
                        Tec9Slide.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("ShMP10");

                        Instance.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("MP10");
                        Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.45f, 0.1f); //Место выстрела

                        foreach (var c in Instance.GetComponents<Collider2D>())
                        {
                            GameObject.Destroy(c);
                        }
                        Instance.AddComponent<PolygonCollider2D>();        
                        Instance.FixColliders();
                        var firearm = Instance.GetComponent<FirearmBehaviour>();
			            Cartridge customCartridge = ModAPI.FindCartridge("50 AE"); //Патрон
                        customCartridge.name = "Weapon"; //Имя
                        customCartridge.Damage *= 0.7f; //Урон
                        customCartridge.StartSpeed *= 0.1f; //Скорость пули
                        customCartridge.PenetrationRandomAngleMultiplier *= 5f; //Точность через объекты
                        customCartridge.Recoil *= 0.2f; //Отдача
                        customCartridge.ImpactForce *= 0f; //Насколько сильно оттолкнет объект
			            firearm.Cartridge = customCartridge;
                        var phys = Instance.GetComponent<PhysicalBehaviour>();
                        phys.Properties = ModAPI.FindPhysicalProperties("Weapon");
                        phys.TrueInitialMass = 0.10f;
                        phys.InitialMass = 0.10f;
                        phys.rigidbody.mass = 0.10f;
  
                        firearm.BulletsPerShot = 1; //Пуль за выстрел
                        firearm.AutomaticFireInterval = 0.12f; //Скорострельность
                        firearm.Automatic = true; //Скорострельный или нет
                        firearm.InitialInaccuracy = 0f; //Разброс
                        
                        ModAPI.KeepExtraObjects(); 
                        firearm.ShotSounds = new AudioClip[]
						{
                            ResourcesLoader.FindSound("SMP5K")
						};          
				    }
				}
            );
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Pistol"),
                    NameOverride = "MP40",
                    NameToOrderByOverride = "+VW3",
                    DescriptionOverride = " ",
                    CategoryOverride = ModAPI.FindCategory("Firearms"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbnail/MP40.png"),
                    AfterSpawn = (Instance) =>
                    {
                        var Tec9Slide = Instance.transform.Find("Slide");
                        Tec9Slide.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("ShMP40");

                        Instance.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("MP40");
                        Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.45f, 0.2f); //Место выстрела

                        foreach (var c in Instance.GetComponents<Collider2D>())
                        {
                            GameObject.Destroy(c);
                        }
                        Instance.AddComponent<PolygonCollider2D>();        
                        Instance.FixColliders();
                        var firearm = Instance.GetComponent<FirearmBehaviour>();
			            Cartridge customCartridge = ModAPI.FindCartridge("50 AE"); //Патрон
                        customCartridge.name = "Weapon"; //Имя
                        customCartridge.Damage *= 0.7f; //Урон
                        customCartridge.StartSpeed *= 0.1f; //Скорость пули
                        customCartridge.PenetrationRandomAngleMultiplier *= 5f; //Точность через объекты
                        customCartridge.Recoil *= 0.2f; //Отдача
                        customCartridge.ImpactForce *= 0f; //Насколько сильно оттолкнет объект
			            firearm.Cartridge = customCartridge;
                        var phys = Instance.GetComponent<PhysicalBehaviour>();
                        phys.Properties = ModAPI.FindPhysicalProperties("Weapon");
                        phys.TrueInitialMass = 0.10f;
                        phys.InitialMass = 0.10f;
                        phys.rigidbody.mass = 0.10f;
  
                        firearm.BulletsPerShot = 1; //Пуль за выстрел
                        firearm.AutomaticFireInterval = 0.09f; //Скорострельность
                        firearm.Automatic = true; //Скорострельный или нет
                        firearm.InitialInaccuracy = 0f; //Разброс
                        
                        ModAPI.KeepExtraObjects(); 
                        firearm.ShotSounds = new AudioClip[]
						{
                            ResourcesLoader.FindSound("SMP40")
						};          
				    }
				}
            );
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Pistol"),
                    NameOverride = "P90",
                    NameToOrderByOverride = "+VW3",
                    DescriptionOverride = " ",
                    CategoryOverride = ModAPI.FindCategory("Firearms"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbnail/P90.png"),
                    AfterSpawn = (Instance) =>
                    {
                        var Tec9Slide = Instance.transform.Find("Slide");
                        Tec9Slide.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("ShP90");

                        Instance.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("P90");
                        Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.38f, 0f); //Место выстрела

                        foreach (var c in Instance.GetComponents<Collider2D>())
                        {
                            GameObject.Destroy(c);
                        }
                        Instance.AddComponent<PolygonCollider2D>();        
                        Instance.FixColliders();
                        var firearm = Instance.GetComponent<FirearmBehaviour>();
			            Cartridge customCartridge = ModAPI.FindCartridge("50 AE"); //Патрон
                        customCartridge.name = "Weapon"; //Имя
                        customCartridge.Damage *= 0.9f; //Урон
                        customCartridge.StartSpeed *= 0.1f; //Скорость пули
                        customCartridge.PenetrationRandomAngleMultiplier *= 5f; //Точность через объекты
                        customCartridge.Recoil *= 0.5f; //Отдача
                        customCartridge.ImpactForce *= 0f; //Насколько сильно оттолкнет объект
			            firearm.Cartridge = customCartridge;
                        var phys = Instance.GetComponent<PhysicalBehaviour>();
                        phys.Properties = ModAPI.FindPhysicalProperties("Weapon");
                        phys.TrueInitialMass = 0.10f;
                        phys.InitialMass = 0.10f;
                        phys.rigidbody.mass = 0.10f;
  
                        firearm.BulletsPerShot = 1; //Пуль за выстрел
                        firearm.AutomaticFireInterval = 0.1f; //Скорострельность
                        firearm.Automatic = true; //Скорострельный или нет
                        firearm.InitialInaccuracy = 0f; //Разброс
                        
                        ModAPI.KeepExtraObjects(); 
                        firearm.ShotSounds = new AudioClip[]
						{
                            ResourcesLoader.FindSound("SP90")
						};          
				    }
				}
            );
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Pistol"),
                    NameOverride = "scorpion",
                    NameToOrderByOverride = "+VW3",
                    DescriptionOverride = " ",
                    CategoryOverride = ModAPI.FindCategory("Firearms"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbnail/scorpion.png"),
                    AfterSpawn = (Instance) =>
                    {
                        var Tec9Slide = Instance.transform.Find("Slide");
                        Tec9Slide.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("Shscorpion");

                        Instance.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("scorpion");
                        Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.25f, 0.1f); //Место выстрела

                        foreach (var c in Instance.GetComponents<Collider2D>())
                        {
                            GameObject.Destroy(c);
                        }
                        Instance.AddComponent<PolygonCollider2D>();        
                        Instance.FixColliders();
                        var firearm = Instance.GetComponent<FirearmBehaviour>();
			            Cartridge customCartridge = ModAPI.FindCartridge("50 AE"); //Патрон
                        customCartridge.name = "Weapon"; //Имя
                        customCartridge.Damage *= 0.6f; //Урон
                        customCartridge.StartSpeed *= 0.1f; //Скорость пули
                        customCartridge.PenetrationRandomAngleMultiplier *= 5f; //Точность через объекты
                        customCartridge.Recoil *= 0.4f; //Отдача
                        customCartridge.ImpactForce *= 0f; //Насколько сильно оттолкнет объект
			            firearm.Cartridge = customCartridge;
                        var phys = Instance.GetComponent<PhysicalBehaviour>();
                        phys.Properties = ModAPI.FindPhysicalProperties("Weapon");
                        phys.TrueInitialMass = 0.10f;
                        phys.InitialMass = 0.10f;
                        phys.rigidbody.mass = 0.10f;
  
                        firearm.BulletsPerShot = 1; //Пуль за выстрел
                        firearm.AutomaticFireInterval = 0.08f; //Скорострельность
                        firearm.Automatic = true; //Скорострельный или нет
                        firearm.InitialInaccuracy = 0f; //Разброс
                        
                        ModAPI.KeepExtraObjects(); 
                        firearm.ShotSounds = new AudioClip[]
						{
                            ResourcesLoader.FindSound("SMP40")
						};          
				    }
				}
            );
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Pistol"),
                    NameOverride = "STEN",
                    NameToOrderByOverride = "+VW3",
                    DescriptionOverride = " ",
                    CategoryOverride = ModAPI.FindCategory("Firearms"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbnail/STEN.png"),
                    AfterSpawn = (Instance) =>
                    {
                        var Tec9Slide = Instance.transform.Find("Slide");
                        Tec9Slide.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("ShSTEN");

                        Instance.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("STEN");
                        Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.4f, 0.05f); //Место выстрела

                        foreach (var c in Instance.GetComponents<Collider2D>())
                        {
                            GameObject.Destroy(c);
                        }
                        Instance.AddComponent<PolygonCollider2D>();        
                        Instance.FixColliders();
                        var firearm = Instance.GetComponent<FirearmBehaviour>();
			            Cartridge customCartridge = ModAPI.FindCartridge("50 AE"); //Патрон
                        customCartridge.name = "Weapon"; //Имя
                        customCartridge.Damage *= 1.2f; //Урон
                        customCartridge.StartSpeed *= 0.1f; //Скорость пули
                        customCartridge.PenetrationRandomAngleMultiplier *= 5f; //Точность через объекты
                        customCartridge.Recoil *= 0.2f; //Отдача
                        customCartridge.ImpactForce *= 0f; //Насколько сильно оттолкнет объект
			            firearm.Cartridge = customCartridge;
                        var phys = Instance.GetComponent<PhysicalBehaviour>();
                        phys.Properties = ModAPI.FindPhysicalProperties("Weapon");
                        phys.TrueInitialMass = 0.10f;
                        phys.InitialMass = 0.10f;
                        phys.rigidbody.mass = 0.10f;
  
                        firearm.BulletsPerShot = 1; //Пуль за выстрел
                        firearm.AutomaticFireInterval = 0.4f; //Скорострельность
                        firearm.Automatic = true; //Скорострельный или нет
                        firearm.InitialInaccuracy = 0f; //Разброс
                        
                        ModAPI.KeepExtraObjects(); 
                        firearm.ShotSounds = new AudioClip[]
						{
                            ResourcesLoader.FindSound("SPM")
						};          
				    }
				}
            );
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Pistol"),
                    NameOverride = "Submachine gun silenced",
                    NameToOrderByOverride = "+VW3",
                    DescriptionOverride = " ",
                    CategoryOverride = ModAPI.FindCategory("Firearms"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbnail/Submachine gun silenced.png"),
                    AfterSpawn = (Instance) =>
                    {
                        var Tec9Slide = Instance.transform.Find("Slide");
                        Tec9Slide.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("ShSubmachine gun silenced");

                        Instance.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("Submachine gun silenced");
                        Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.45f, 0.1f); //Место выстрела

                        foreach (var c in Instance.GetComponents<Collider2D>())
                        {
                            GameObject.Destroy(c);
                        }
                        Instance.AddComponent<PolygonCollider2D>();        
                        Instance.FixColliders();
                        var firearm = Instance.GetComponent<FirearmBehaviour>();
			            Cartridge customCartridge = ModAPI.FindCartridge("50 AE"); //Патрон
                        customCartridge.name = "Weapon"; //Имя
                        customCartridge.Damage *= 0.8f; //Урон
                        customCartridge.StartSpeed *= 0.1f; //Скорость пули
                        customCartridge.PenetrationRandomAngleMultiplier *= 5f; //Точность через объекты
                        customCartridge.Recoil *= 0.2f; //Отдача
                        customCartridge.ImpactForce *= 0f; //Насколько сильно оттолкнет объект
			            firearm.Cartridge = customCartridge;
                        var phys = Instance.GetComponent<PhysicalBehaviour>();
                        phys.Properties = ModAPI.FindPhysicalProperties("Weapon");
                        phys.TrueInitialMass = 0.10f;
                        phys.InitialMass = 0.10f;
                        phys.rigidbody.mass = 0.10f;
  
                        firearm.BulletsPerShot = 1; //Пуль за выстрел
                        firearm.AutomaticFireInterval = 0.06f; //Скорострельность
                        firearm.Automatic = true; //Скорострельный или нет
                        firearm.InitialInaccuracy = 0f; //Разброс
                        
                        ModAPI.KeepExtraObjects(); 
                        firearm.ShotSounds = new AudioClip[]
						{
                            ResourcesLoader.FindSound("Silenced 1")
						};          
				    }
				}
            );
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Pistol"),
                    NameOverride = "Thompson",
                    NameToOrderByOverride = "+VW3",
                    DescriptionOverride = " ",
                    CategoryOverride = ModAPI.FindCategory("Firearms"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbnail/Thompson.png"),
                    AfterSpawn = (Instance) =>
                    {
                        var Tec9Slide = Instance.transform.Find("Slide");
                        Tec9Slide.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("ShThompson");

                        Instance.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("Thompson");
                        Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.55f, 0.1f); //Место выстрела

                        foreach (var c in Instance.GetComponents<Collider2D>())
                        {
                            GameObject.Destroy(c);
                        }
                        Instance.AddComponent<PolygonCollider2D>();        
                        Instance.FixColliders();
                        var firearm = Instance.GetComponent<FirearmBehaviour>();
			            Cartridge customCartridge = ModAPI.FindCartridge("50 AE"); //Патрон
                        customCartridge.name = "Weapon"; //Имя
                        customCartridge.Damage *= 0.8f; //Урон
                        customCartridge.StartSpeed *= 0.1f; //Скорость пули
                        customCartridge.PenetrationRandomAngleMultiplier *= 5f; //Точность через объекты
                        customCartridge.Recoil *= 0.2f; //Отдача
                        customCartridge.ImpactForce *= 0f; //Насколько сильно оттолкнет объект
			            firearm.Cartridge = customCartridge;
                        var phys = Instance.GetComponent<PhysicalBehaviour>();
                        phys.Properties = ModAPI.FindPhysicalProperties("Weapon");
                        phys.TrueInitialMass = 0.10f;
                        phys.InitialMass = 0.10f;
                        phys.rigidbody.mass = 0.10f;
  
                        firearm.BulletsPerShot = 1; //Пуль за выстрел
                        firearm.AutomaticFireInterval = 0.13f; //Скорострельность
                        firearm.Automatic = true; //Скорострельный или нет
                        firearm.InitialInaccuracy = 0f; //Разброс
                        
                        ModAPI.KeepExtraObjects(); 
                        firearm.ShotSounds = new AudioClip[]
						{
                            ResourcesLoader.FindSound("SThompson")
						};          
				    }
				}
            );
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Pistol"),
                    NameOverride = "UZI",
                    NameToOrderByOverride = "+VW3",
                    DescriptionOverride = " ",
                    CategoryOverride = ModAPI.FindCategory("Firearms"),
                    ThumbnailOverride = ModAPI.LoadSprite("Thumbnail/UZI.png"),
                    AfterSpawn = (Instance) =>
                    {
                        var Tec9Slide = Instance.transform.Find("Slide");
                        Tec9Slide.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("ShUZI");

                        Instance.GetComponent<SpriteRenderer>().sprite = ResourcesLoader.FindSprite("UZI");
                        Instance.GetComponent<FirearmBehaviour>().barrelPosition = new Vector2(0.25f, 0.1f); //Место выстрела

                        foreach (var c in Instance.GetComponents<Collider2D>())
                        {
                            GameObject.Destroy(c);
                        }
                        Instance.AddComponent<PolygonCollider2D>();        
                        Instance.FixColliders();
                        var firearm = Instance.GetComponent<FirearmBehaviour>();
			            Cartridge customCartridge = ModAPI.FindCartridge("50 AE"); //Патрон
                        customCartridge.name = "Weapon"; //Имя
                        customCartridge.Damage *= 0.5f; //Урон
                        customCartridge.StartSpeed *= 0.1f; //Скорость пули
                        customCartridge.PenetrationRandomAngleMultiplier *= 5f; //Точность через объекты
                        customCartridge.Recoil *= 0.4f; //Отдача
                        customCartridge.ImpactForce *= 0f; //Насколько сильно оттолкнет объект
			            firearm.Cartridge = customCartridge;
                        var phys = Instance.GetComponent<PhysicalBehaviour>();
                        phys.Properties = ModAPI.FindPhysicalProperties("Weapon");
                        phys.TrueInitialMass = 0.10f;
                        phys.InitialMass = 0.10f;
                        phys.rigidbody.mass = 0.10f;
  
                        firearm.BulletsPerShot = 1; //Пуль за выстрел
                        firearm.AutomaticFireInterval = 0.07f; //Скорострельность
                        firearm.Automatic = true; //Скорострельный или нет
                        firearm.InitialInaccuracy = 0f; //Разброс
                        
                        ModAPI.KeepExtraObjects(); 
                        firearm.ShotSounds = new AudioClip[]
						{
                            ResourcesLoader.FindSound("SMicro Uzi")
						};          
				    }
				}
            );
        }
    }
    public class BurstFireAdapter : MonoBehaviour
    {
        public float Interval = 0.1f;
        public int BurstCount = 5;

        private bool busy = false;

        private CanShoot firearm;

        private void Awake()
        {
            firearm = GetComponent<CanShoot>();
        }

        private void Use()
        {
            StartCoroutine(Burst());
        }

        private System.Collections.IEnumerator Burst()
        {
            if (busy) yield break;
            busy = true;
            for (int i = 0; i < BurstCount - 1; i++)
            {
                yield return new WaitForSeconds(Interval);
                firearm.Shoot();
            }
            busy = false;
        }
    } 
}   